@@ -330,17 +330,17 @@ def build2():
     # ensure yarn installs all build tools
     local("pwd")
     local('mvn clean install -DskipTests')
-    local('mkdir -p deploy/api')
-    local('mkdir -p deploy/worker')
-
-    local('cp config/ deploy/api/config')
+    local('mkdir -p deploy/api/config')
+    local('mkdir -p deploy/api/lib')
+    local('mkdir -p deploy/worker/config')
+    local('mkdir -p deploy/worker/lib')
  
     local('cp config/keyset-prod.json deploy/api/config/keyset.json')
     local('cp config/logback.xml deploy/api/config/')
     local('cp config/application-prod.yml deploy/api/config/')
 
     local('cp -r api/target/lib/ deploy/api/')
-    
+
     local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
     local('cp config/keyset-prod.json deploy/worker/config/keyset.json')
